Module sql

Module sql 

Modules

name
window

Structs

SqlFilter
WHERE-fragment accumulator that keeps predicates and bind values in the same order they are introduced.
SqlFragment
SQL text plus the positional parameters introduced by that text.

Functions

total_matched_bigint_expr
SQL window-count expression forced to DuckDB BIGINT.
total_matched_expr
SQL window-count expression for list queries that carry total_matched on each returned row.
where_clause