pub struct IntervalSampleScope {
pub start_expr: String,
pub end_expr: String,
pub where_clause: String,
pub params: Vec<Value>,
}Expand description
Scope for positive interval samples that may be clipped to a user time window before aggregation.
Fields
start_expr: Stringend_expr: Stringwhere_clause: Stringparams: Vec<Value>Trait Implementations
Sourceimpl Clone for IntervalSampleScope
impl Clone for IntervalSampleScope
Sourcefn clone(&self) -> IntervalSampleScope
fn clone(&self) -> IntervalSampleScope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntervalSampleScope
impl Debug for IntervalSampleScope
Sourceimpl PartialEq for IntervalSampleScope
impl PartialEq for IntervalSampleScope
Sourcefn eq(&self, other: &IntervalSampleScope) -> bool
fn eq(&self, other: &IntervalSampleScope) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IntervalSampleScope