Modules
Structs
- SqlFilter
- WHERE-fragment accumulator that keeps predicates and bind values in the same order they are introduced.
- SqlFragment
- SQL text plus the positional parameters introduced by that text.
Functions
- total_
matched_ bigint_ expr - SQL window-count expression forced to DuckDB BIGINT.
- total_
matched_ expr - SQL window-count expression for list queries that carry
total_matchedon each returned row. - where_
clause